#! /bin/bash
# /etc/init.d/exim
#
# Written by Miquel van Smoorenburg <miquels@drinkel.ow.org>.
# Modified for Debian GNU/Linux by Ian Murdock <imurdock@gnu.ai.mit.edu>.
# Modified for exim by Tim Cutts <timc@chiark.greenend.org.uk>
# Enhanced by Marc MERLIN <marc_soft@merlins.org>

set -e

# Exit if exim runs from /etc/inetd.conf
if grep -q "^ *smtp" /etc/inetd.conf; then
    exit 0
fi

DAEMON=/usr/sbin/exim
NAME=exim

test -x $DAEMON || exit 0

updateconfig () {
    if test -e /etc/mail/Makefile && grep -q exim /etc/mail/Makefile ; then (cd /etc/mail; make exim); fi
    if test -e /etc/mail/virtualdomains/Makefile && type cdbmake &>/dev/null; then (cd /etc/mail/virtualdomains; make ); fi
}

case "$1" in
  start)
    echo -n "Starting MTA: "
    updateconfig
    start-stop-daemon --start --exec $DAEMON -- -bd -q30m
    # Let's listen on another port for ISPs that block outbound 25
    start-stop-daemon --start --exec $DAEMON --name dummy  -- -oX 2525 -bd -q30m
    # Old TLS port
    start-stop-daemon --start --exec $DAEMON --name dummy  -- -oX 465 -bd -q30m
    echo "exim."
    ;;
  stop)
    echo -n "Stopping MTA: "
    start-stop-daemon --stop --oknodo --exec $DAEMON
    echo "exim."
      ;;
  restart)
    echo "Restarting MTA: "
    start-stop-daemon --stop --oknodo --exec $DAEMON
    updateconfig
    start-stop-daemon --start --exec $DAEMON -- -bd -q30m
    # Let's listen on another port for ISPs that block outbound 25
    start-stop-daemon --start --exec $DAEMON --name dummy  -- -oX 2525 -bd -q30m
    # Old TLS port
    start-stop-daemon --start --exec $DAEMON --name dummy  -- -oX 465 -bd -q30m
    echo "exim."
    ;;
  reload|force-reload)
    echo "Reloading $NAME configuration files (won't work for exims on alternate ports)"
    updateconfig
    start-stop-daemon --stop --signal 1 --exec $DAEMON
    ;;
  *)
    echo "Usage: /etc/init.d/$NAME {start|stop|reload}"
    exit 1
    ;;
esac

exit 0
